Welcome to MIDIOgre's documentation!
==================================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

API Documentation
===============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
   midiogre
   midiogre.augmentations
   midiogre.core

Examples
========

.. toctree::
   :maxdepth: 2
   :caption: Examples:

   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search` 